abergm(formula, burn.in = 100, main.iters = 1000, aux.iters = 1000, m.prior = NULL, sigma.prior = NULL, nchains = NULL, gamma = 0.5, method = 'Adaptive.chains', rectangular = TRUE, sigma.epsilon = NULL, updategap = 10, ...)R formula object, of the form network object and ergm-terms.
nchains is set to 1.
gamma is used as variance of the Normal proposal distribution.
ADS = adaptive direction sampling, Adaptive.past = adaptive strategy where past parameter particles are used, Adaptive.chains (default) = adaptive strategy all particles at the current time for all chains are used.
Adaptive.past is used, it defines the type of adaptive strategy: if TRUE (default) = all parameter particles from all chains and all past simulations are used, if FALSE = all parameter particles along the same chain and all are used.
sigma.espilon is set equal to gamma.
bergm
data(molecule)
mol <- abergm(molecule ~ edges + kstar(2),
burn.in = 50,
aux.iters = 50,
main.iters = 500,
method = 'Adaptive.chains',
nchains = 4,
gamma = 1)
Run the code above in your browser using DataLab